from cv2utils.haar_cascade import FaceCascade
from cv2utils.haar_cascade import EyeCascade
from cv2utils.opencv_dnn import FaceDnn

__all__ = ["FaceCascade",
           "EyeCascade",
           "FaceDnn"]
